pub enum NetworkUpgrade {
Overwinter,
Sapling,
Blossom,
Heartwood,
Canopy,
Nu5,
ZFuture,
}Expand description
An event that occurs at a specified height on the Zcash chain, at which point the consensus rules enforced by the network are altered.
See ZIP 200 for more details.
Variants
Overwinter
The Overwinter network upgrade.
Sapling
The Sapling network upgrade.
Blossom
The Blossom network upgrade.
Heartwood
The Heartwood network upgrade.
Canopy
The Canopy network upgrade.
Nu5
The Nu5 network upgrade.
ZFuture
The ZFUTURE network upgrade.
This upgrade is expected never to activate on mainnet; it is intended for use in integration testing of functionality that is a candidate for integration in a future network upgrade.