pub struct ExtendedSpendingKey {
pub expsk: ExpandedSpendingKey,
/* private fields */
}Expand description
A Sapling extended spending key
Fields
expsk: ExpandedSpendingKeyImplementations
Sourceimpl ExtendedSpendingKey
impl ExtendedSpendingKey
pub fn master(seed: &[u8]) -> Self
pub fn read<R: Read>(reader: R) -> Result<Self>
pub fn write<W: Write>(&self, writer: W) -> Result<()>
Sourcepub fn from_path(master: &ExtendedSpendingKey, path: &[ChildIndex]) -> Self
pub fn from_path(master: &ExtendedSpendingKey, path: &[ChildIndex]) -> Self
Returns the child key corresponding to the path derived from the master key
pub fn derive_child(&self, i: ChildIndex) -> Self
Sourcepub fn default_address(&self) -> (DiversifierIndex, PaymentAddress)
pub fn default_address(&self) -> (DiversifierIndex, PaymentAddress)
Returns the address with the lowest valid diversifier index, along with the diversifier index that generated that address.
Sourcepub fn derive_internal(&self) -> Self
pub fn derive_internal(&self) -> Self
Derives an internal spending key given an external spending key.
Specified in ZIP 32.